'use strict';

exports.__esModule = true;
exports.eventSegments = eventSegments;
exports.segStyle = segStyle;
exports.eventLevels = eventLevels;
exports.inRange = inRange;
exports.segsOverlap = segsOverlap;
exports.sortEvents = sortEvents;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _dates = require('./dates');

var _dates2 = _interopRequireDefault(_dates);

var _localizer = require('../localizer');

var _localizer2 = _interopRequireDefault(_localizer);

var _accessors = require('./accessors');

//import canUseDom from 'dom-helpers/util/inDOM';

// let isIE = false;

// if (canUseDom) {
//   isIE = ('documentMode' in document)
// }

function eventSegments(event, first, last, _ref) {
  var startAccessor = _ref.startAccessor;
  var endAccessor = _ref.endAccessor;
  var culture = _ref.culture;

  var startOfWeek = _localizer2['default'].startOfWeek(culture);
  var start = _dates2['default'].duration(first, _dates2['default'].max(_accessors.accessor(event, startAccessor), first), 'weekday', startOfWeek);

  var span = Math.min(_dates2['default'].duration(_dates2['default'].max(_accessors.accessor(event, startAccessor), first), _dates2['default'].min(_accessors.accessor(event, endAccessor), _dates2['default'].add(last, 1, 'day')), 'day'), 7);

  span = Math.max(span, 1);

  return {
    event: event,
    span: span,
    left: start + 1,
    right: Math.max(start + span, 1)
  };
}

function segStyle(span, slots) {
  var per = span / slots * 100 + '%';
  return { flexBasis: per, maxWidth: per } // IE10/11 need max-width. flex-basis doesn't respect box-sizing
  ;
}

function eventLevels(rowSegments) {
  var limit = arguments[1] === undefined ? Infinity : arguments[1];

  var i = undefined,
      j = undefined,
      seg = undefined,
      levels = [],
      extra = [];

  for (i = 0; i < rowSegments.length; i++) {
    seg = rowSegments[i];

    for (j = 0; j < levels.length; j++) if (!segsOverlap(seg, levels[j])) break;

    if (j >= limit) {
      extra.push(seg);
    } else {
      (levels[j] || (levels[j] = [])).push(seg);
    }
  }

  for (i = 0; i < levels.length; i++) {
    levels[i].sort(function (a, b) {
      return a.left - b.left;
    }); //eslint-disable-line
  }

  return { levels: levels, extra: extra };
}

function inRange(e, start, end, _ref2) {
  var startAccessor = _ref2.startAccessor;
  var endAccessor = _ref2.endAccessor;

  var eStart = _accessors.accessor(e, startAccessor);
  var eEnd = _accessors.accessor(e, endAccessor);

  var starts = _dates2['default'].inRange(eStart, start, end, 'day');
  var during = _dates2['default'].lt(eStart, start, 'day') && _dates2['default'].gt(eEnd, end, 'day');
  var ends = _dates2['default'].lt(eStart, start) && _dates2['default'].inRange(eEnd, start, end, 'day');

  return starts || ends || during;
}

function segsOverlap(seg, otherSegs) {
  return otherSegs.some(function (otherSeg) {
    return otherSeg.left <= seg.right && otherSeg.right >= seg.left;
  });
}

function sortEvents(evtA, evtB, _ref3) {
  var startAccessor = _ref3.startAccessor;
  var endAccessor = _ref3.endAccessor;
  var allDayAccessor = _ref3.allDayAccessor;

  var durA = _dates2['default'].duration(_accessors.accessor(evtA, startAccessor), _accessors.accessor(evtA, endAccessor), 'day'),
      durB = _dates2['default'].duration(_accessors.accessor(evtB, startAccessor), _accessors.accessor(evtB, endAccessor), 'day');

  return +_accessors.accessor(evtA, startAccessor) - +_accessors.accessor(evtB, startAccessor) || durB - durA || !!_accessors.accessor(evtA, allDayAccessor) - !!_accessors.accessor(evtB, allDayAccessor);
}